==> spip_4.1.5+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_sv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=sv
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'endast för framtida artiklar (ingen inverkan på databasen).',
	'bouton_radio_articles_tous' => 'på alla artiklar utan undantag.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'på alla artiklar utom de utan forum.',
	'bouton_radio_enregistrement_obligatoire' => 'Krav på registrering (användare måste registrera sig genom att tillhandahålla sin e-postadress innan de kan bidra).  being able to post contributions).',
	'bouton_radio_moderation_priori' => 'Moderering i förhand (bidrag visas endast efter att de godkänts av en administatör).', # MODIF
	'bouton_radio_modere_abonnement' => 'registrering krävs',
	'bouton_radio_modere_posteriori' => 'moderering i efterhand', # MODIF
	'bouton_radio_modere_priori' => 'moderering i förhand', # MODIF
	'bouton_radio_publication_immediate' => 'Omedelbar publicering av meddelanden (bidrag visas direkt efter att de skickas, administratörer kan radera dom senare):',

	// D
	'documents_interdits_forum' => 'Dokument är inte tillåtna i forumet',

	// F
	'form_pet_message_commentaire' => 'Något meddelande eller kommentar?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Du har inte längre tillgång till dessa forum.',
	'forum_attention_dix_caracteres' => '<b>Varning!</b> Ditt meddelande måste vara minst 10 tecken långt.',
	'forum_attention_trois_caracteres' => '<b>Varning!</b> Din rubrik måste vara minst tre tecken lång.',
	'forum_attention_trop_caracteres' => '<b>Warning !</b> Ditt meddelande är för långt (@compte@ characters) : För att det skall kunna skrivas får meddelandet inte innehålla mer än @max@ tecken.', # MODIF
	'forum_avez_selectionne' => 'Du har valt:',
	'forum_cliquer_retour' => 'Klicka <a href=\'@retour_forum@\'>här</a> för att fortsätta.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Detta forum är modererat: ditt bidrag kommer att synas först när någon moderator har godkänt  det.', # MODIF
	'forum_lien_hyper' => '<b>Länk</b> (valfritt)', # MODIF
	'forum_message_definitif' => 'Slutligt meddelande: skicka till sajten',
	'forum_message_trop_long' => 'Ditt meddelande är för långt. Det får inte vara mer än 2000 tecken.', # MODIF
	'forum_ne_repondez_pas' => 'Svara inte på detta brev utan i forumet på denna adress:', # MODIF
	'forum_page_url' => '(Om ditt meddelande refererar till en artikel publicerad på webben eller till en sida med mer information, ange namnet på sidan och dess adress nedan).',
	'forum_poste_par' => 'Meddelande inskickat@parauteur@ efter din artikel', # MODIF
	'forum_qui_etes_vous' => '<b>Vem är du?</b> (valfritt)', # MODIF
	'forum_texte' => 'Texten i meddelandet:', # MODIF
	'forum_titre' => 'Ämne:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Granska valet',
	'forum_voir_avant' => 'Förhandsgranska meddelandet innan du skickar det', # MODIF
	'forum_votre_email' => 'Din epost-adress', # MODIF
	'forum_votre_nom' => 'Ditt namn (eller alias):', # MODIF
	'forum_vous_enregistrer' => 'För att delta
 i detta forum måste du vara registrerad. Var vänlig
  att skriv in ditt användarnamn som du fick.
 Om du inte är registrerad, måste du  ',
	'forum_vous_inscrire' => 'registrera dig.',

	// I
	'icone_poster_message' => 'Anslå ett meddelande',
	'icone_suivi_forum' => 'Uppföljning av publika forum: @nb_forums@ bidrag',
	'icone_suivi_forums' => 'Hantera forumen',
	'icone_supprimer_message' => 'Radera meddelandet',
	'icone_valider_message' => 'Godkänn meddelandet',
	'info_activer_forum_public' => '<i>för att aktivera publika forum, var vänlig och välj moderationssätt:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aktivera ditt val av moderering:',
	'info_desactiver_forum_public' => 'Avaktivera de publika forumen.
 Publika forum kan tillåtas  för
 enskilda artiklar; de kommer inte att vara aktiva för avdelningae, nyheter, osv.',
	'info_envoi_forum' => 'Skicka foruminlägg till artikelredaktörerna',
	'info_liens_syndiques_3' => 'forum',
	'info_liens_syndiques_4' => 'är',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'är',
	'info_liens_syndiques_7' => 'i väntan på validering.',
	'info_mode_fonctionnement_defaut_forum_public' => 'Valt funktionssätt för de publika forumen',
	'info_pas_de_forum' => 'inget forum',
	'item_activer_forum_administrateur' => 'Aktivera administratörernas forum',
	'item_config_forums_prive_global' => 'Aktivera redaktörernas forum',
	'item_config_forums_prive_objets' => 'Aktivera dessa forum',
	'item_desactiver_forum_administrateur' => 'Avaktivera administratörernas forum',
	'item_non_config_forums_prive_global' => 'Avaktivera redaktörernas forum',
	'item_non_config_forums_prive_objets' => 'Avaktivera dessa forum',

	// L
	'lien_reponse_article' => 'Svara på artikeln',
	'lien_reponse_breve_2' => 'Skriv ett svar på nyheten',
	'lien_reponse_rubrique' => 'Skriv ett svar till avdelningen',

	// O
	'onglet_messages_internes' => 'Interna meddelanden',
	'onglet_messages_publics' => 'Publika meddelanden',
	'onglet_messages_vide' => 'Meddelanden utan text',

	// R
	'repondre_message' => 'Svara på meddelandet',

	// S
	'statut_original' => 'original',

	// T
	'titre_cadre_forum_administrateur' => 'Administratörernas privata forum ',
	'titre_cadre_forum_interne' => 'Internt forum',
	'titre_forum' => 'Forum'
);

==> spip_4.2.14+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_sv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=sv
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'endast för framtida artiklar (ingen inverkan på databasen).',
	'bouton_radio_articles_tous' => 'på alla artiklar utan undantag.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'på alla artiklar utom de utan forum.',
	'bouton_radio_enregistrement_obligatoire' => 'Krav på registrering (användare måste registrera sig genom att tillhandahålla sin e-postadress innan de kan bidra).  being able to post contributions).',
	'bouton_radio_moderation_priori' => 'Moderering i förhand (bidrag visas endast efter att de godkänts av en administatör).', # MODIF
	'bouton_radio_modere_abonnement' => 'registrering krävs',
	'bouton_radio_modere_posteriori' => 'moderering i efterhand', # MODIF
	'bouton_radio_modere_priori' => 'moderering i förhand', # MODIF
	'bouton_radio_publication_immediate' => 'Omedelbar publicering av meddelanden (bidrag visas direkt efter att de skickas, administratörer kan radera dom senare):',

	// D
	'documents_interdits_forum' => 'Dokument är inte tillåtna i forumet',

	// F
	'form_pet_message_commentaire' => 'Något meddelande eller kommentar?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Du har inte längre tillgång till dessa forum.',
	'forum_attention_dix_caracteres' => '<b>Varning!</b> Ditt meddelande måste vara minst 10 tecken långt.',
	'forum_attention_trois_caracteres' => '<b>Varning!</b> Din rubrik måste vara minst tre tecken lång.',
	'forum_attention_trop_caracteres' => '<b>Warning !</b> Ditt meddelande är för långt (@compte@ characters) : För att det skall kunna skrivas får meddelandet inte innehålla mer än @max@ tecken.', # MODIF
	'forum_avez_selectionne' => 'Du har valt:',
	'forum_cliquer_retour' => 'Klicka <a href=\'@retour_forum@\'>här</a> för att fortsätta.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Detta forum är modererat: ditt bidrag kommer att synas först när någon moderator har godkänt  det.', # MODIF
	'forum_lien_hyper' => '<b>Länk</b> (valfritt)', # MODIF
	'forum_message_definitif' => 'Slutligt meddelande: skicka till sajten',
	'forum_message_trop_long' => 'Ditt meddelande är för långt. Det får inte vara mer än 2000 tecken.', # MODIF
	'forum_ne_repondez_pas' => 'Svara inte på detta brev utan i forumet på denna adress:', # MODIF
	'forum_page_url' => '(Om ditt meddelande refererar till en artikel publicerad på webben eller till en sida med mer information, ange namnet på sidan och dess adress nedan).',
	'forum_poste_par' => 'Meddelande inskickat@parauteur@ efter din artikel', # MODIF
	'forum_qui_etes_vous' => '<b>Vem är du?</b> (valfritt)', # MODIF
	'forum_texte' => 'Texten i meddelandet:', # MODIF
	'forum_titre' => 'Ämne:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Granska valet',
	'forum_voir_avant' => 'Förhandsgranska meddelandet innan du skickar det', # MODIF
	'forum_votre_email' => 'Din epost-adress', # MODIF
	'forum_votre_nom' => 'Ditt namn (eller alias):', # MODIF
	'forum_vous_enregistrer' => 'För att delta
 i detta forum måste du vara registrerad. Var vänlig
  att skriv in ditt användarnamn som du fick.
 Om du inte är registrerad, måste du  ',
	'forum_vous_inscrire' => 'registrera dig.',

	// I
	'icone_poster_message' => 'Anslå ett meddelande',
	'icone_suivi_forum' => 'Uppföljning av publika forum: @nb_forums@ bidrag',
	'icone_suivi_forums' => 'Hantera forumen',
	'icone_supprimer_message' => 'Radera meddelandet',
	'icone_valider_message' => 'Godkänn meddelandet',
	'info_activer_forum_public' => '<i>för att aktivera publika forum, var vänlig och välj moderationssätt:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aktivera ditt val av moderering:',
	'info_desactiver_forum_public' => 'Avaktivera de publika forumen.
 Publika forum kan tillåtas  för
 enskilda artiklar; de kommer inte att vara aktiva för avdelningae, nyheter, osv.',
	'info_envoi_forum' => 'Skicka foruminlägg till artikelredaktörerna',
	'info_liens_syndiques_3' => 'forum',
	'info_liens_syndiques_4' => 'är',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'är',
	'info_liens_syndiques_7' => 'i väntan på validering.',
	'info_mode_fonctionnement_defaut_forum_public' => 'Valt funktionssätt för de publika forumen',
	'info_pas_de_forum' => 'inget forum',
	'item_activer_forum_administrateur' => 'Aktivera administratörernas forum',
	'item_config_forums_prive_global' => 'Aktivera redaktörernas forum',
	'item_config_forums_prive_objets' => 'Aktivera dessa forum',
	'item_desactiver_forum_administrateur' => 'Avaktivera administratörernas forum',
	'item_non_config_forums_prive_global' => 'Avaktivera redaktörernas forum',
	'item_non_config_forums_prive_objets' => 'Avaktivera dessa forum',

	// L
	'lien_reponse_article' => 'Svara på artikeln',
	'lien_reponse_breve_2' => 'Skriv ett svar på nyheten',
	'lien_reponse_rubrique' => 'Skriv ett svar till avdelningen',

	// O
	'onglet_messages_internes' => 'Interna meddelanden',
	'onglet_messages_publics' => 'Publika meddelanden',
	'onglet_messages_vide' => 'Meddelanden utan text',

	// R
	'repondre_message' => 'Svara på meddelandet',

	// S
	'statut_original' => 'original',

	// T
	'titre_cadre_forum_administrateur' => 'Administratörernas privata forum ',
	'titre_cadre_forum_interne' => 'Internt forum',
	'titre_forum' => 'Forum',
];
